#ifndef THREADS_H_INCLUDED
#define THREADS_H_INCLUDED

#include <glib.h>

void start_thread_view(GList*, gchar *id_, gchar *params, int index);
void add_message_to_list(gpointer data, int i);
void add_comment();
void end_single_thread();

#endif
